aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation
diff options
context:
space:
mode:
authorRoy Ben Shabat <Roy.mail.net@gmail.com>2018-07-15 01:04:34 +0300
committerRoy Ben Shabat <Roy.mail.net@gmail.com>2018-07-15 01:04:34 +0300
commitcc425e019d3a7d3494ac15ffe213b6b47b1c64ed (patch)
tree6db5ec969f92f91c2d05af55216bc4a267cc2370 /Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation
parent64bcf92608faae31b7cd31ac3da5c7d1d7ebcd0b (diff)
downloadTango-cc425e019d3a7d3494ac15ffe213b6b47b1c64ed.tar.gz
Tango-cc425e019d3a7d3494ac15ffe213b6b47b1c64ed.zip
Working on PPC.
Diffstat (limited to 'Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation')
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation/INavigationManager.cs14
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation/INavigationObjectReceiver.cs13
2 files changed, 26 insertions, 1 deletions
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation/INavigationObjectReceiver.cs b/Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation/INavigationObjectReceiver.cs
new file mode 100644
index 000000000..8c906b106
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation/INavigationObjectReceiver.cs
@@ -0,0 +1,13 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+
+namespace Tango.PPC.Common.Navigation
+{
+ public interface INavigationObjectReceiver<T>
+ {
+ void OnNavigatedToWithObject(T obj);
+ }
+}
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation/INavigationManager.cs b/Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation/INavigationManager.cs
index 2dba3a60b..249a917de 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation/INavigationManager.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.Common/Navigation/INavigationManager.cs
@@ -68,11 +68,23 @@ namespace Tango.PPC.Common.Navigation
Task<bool> NavigateTo(String fullPath, bool pushToHistory = true);
/// <summary>
/// Navigates to the specified module and view by full path (e.g Jobs.JobsView).
/// The view must be of type INavigationResultProvider<TResult>.
/// </summary>
/// <param name="fullPath">The full path.</param>
Task<TResult> NavigateForResult<TModule, TView, TResult, TPass>(TPass obj, bool pushToHistory = true)
where TModule : IPPCModule;
+
+ /// <summary>
+ /// Navigates to the specified module and view with the specified object.
+ /// </summary>
+ /// <typeparam name="TModule">The type of the module.</typeparam>
+ /// <typeparam name="TView">The type of the view.</typeparam>
+ /// <typeparam name="TPass">The type of the pass.</typeparam>
+ /// <param name="obj">The object.</param>
+ /// <param name="pushToHistory">if set to <c>true</c> [push to history].</param>
+ /// <returns></returns>
+ Task<bool> NavigateWithObject<TModule, TView, TPass>(TPass obj, bool pushToHistory = true)
+ where TModule : IPPCModule;
}
}
@@ -68,11 +68,23 @@ namespace Tango.PPC.Common.Navigation
Task<bool> NavigateTo(String fullPath, bool pushToHistory = true);
/// <summary>
- /// Navigates to the specified module and view by full path (e.g Jobs.JobsView).
+ /// Navigates to the specified module and view with the specified object and expecting a return parameter.
/// The view must be of type INavigationResultProvider<TResult>.
/// </summary>